#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IGroup_VERSION = "3.1.28078"

class IGroup(BaseEndpoint):
	def __init__(self, apiKey, url ,domainUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/groups/{domainUid}'
		self.domainUid_ = domainUid
		self.base = self.base.replace('{domainUid}',domainUid)

	def allUids (self):
		postUri = "/_alluids";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def update (self, uid , group ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		__data__ = __GroupSerDer__().encode(group)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def byName (self, name ):
		postUri = "/byName/{name}";
		__data__ = None
		postUri = postUri.replace("{name}",name);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def remove (self, uid , members ):
		postUri = "/{uid}/members";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.group.api.Member import Member
		from netbluemind.group.api.Member import __MemberSerDer__
		__data__ = serder.ListSerDer(__MemberSerDer__()).encode(members)

		queryParams = {    };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getParents (self, uid ):
		postUri = "/{uid}/parents";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
	def search (self, query ):
		postUri = "/_search";
		__data__ = None
		from netbluemind.group.api.GroupSearchQuery import GroupSearchQuery
		from netbluemind.group.api.GroupSearchQuery import __GroupSearchQuerySerDer__
		__data__ = __GroupSearchQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
	def byEmail (self, email ):
		postUri = "/byEmail/{email}";
		__data__ = None
		postUri = postUri.replace("{email}",email);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
	def create (self, uid , group ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		__data__ = __GroupSerDer__().encode(group)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def setRoles (self, uid , roles ):
		postUri = "/{uid}/roles";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.SetSerDer(serder.STRING).encode(roles)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getExpandedUsersMembers (self, uid ):
		postUri = "/{uid}/expandedusersmembers";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Member import Member
		from netbluemind.group.api.Member import __MemberSerDer__
		return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)
	def getRoles (self, uid ):
		postUri = "/{uid}/roles";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def add (self, uid , members ):
		postUri = "/{uid}/members";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.group.api.Member import Member
		from netbluemind.group.api.Member import __MemberSerDer__
		__data__ = serder.ListSerDer(__MemberSerDer__()).encode(members)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getByExtId (self, extid ):
		postUri = "/_extid/{extid}";
		__data__ = None
		postUri = postUri.replace("{extid}",extid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
	def touch (self, uid ):
		postUri = "/{uid}/_touch";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def setExtId (self, uid , arg1 ):
		postUri = "/{uid}/_extId";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.STRING.encode(arg1)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
	def getGroupsWithRoles (self, roles ):
		postUri = "/_rolegroups";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(roles)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def createWithExtId (self, uid , extid , group ):
		postUri = "/{uid}/{extid}/createwithextid";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		postUri = postUri.replace("{extid}",extid);
		from netbluemind.group.api.Group import Group
		from netbluemind.group.api.Group import __GroupSerDer__
		__data__ = __GroupSerDer__().encode(group)

		queryParams = {     };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getMembers (self, uid ):
		postUri = "/{uid}/members";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = json.dumps(__data__));
		from netbluemind.group.api.Member import Member
		from netbluemind.group.api.Member import __MemberSerDer__
		return self.handleResult__(serder.ListSerDer(__MemberSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Restorable :
	def __init__( self):
		self.kind = None
		self.entryUid = None
		self.domainUid = None
		self.displayName = None
		pass

class __RestorableSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Restorable()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.dataprotect.api.RestorableKind import RestorableKind
		from netbluemind.dataprotect.api.RestorableKind import __RestorableKindSerDer__
		kindValue = value['kind']
		instance.kind = __RestorableKindSerDer__().parse(kindValue)
		entryUidValue = value['entryUid']
		instance.entryUid = serder.STRING.parse(entryUidValue)
		domainUidValue = value['domainUid']
		instance.domainUid = serder.STRING.parse(domainUidValue)
		displayNameValue = value['displayName']
		instance.displayName = serder.STRING.parse(displayNameValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.dataprotect.api.RestorableKind import RestorableKind
		from netbluemind.dataprotect.api.RestorableKind import __RestorableKindSerDer__
		kindValue = value.kind
		instance["kind"] = __RestorableKindSerDer__().encode(kindValue)
		entryUidValue = value.entryUid
		instance["entryUid"] = serder.STRING.encode(entryUidValue)
		domainUidValue = value.domainUid
		instance["domainUid"] = serder.STRING.encode(domainUidValue)
		displayNameValue = value.displayName
		instance["displayName"] = serder.STRING.encode(displayNameValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class StoragePolicy :
	def __init__( self):
		self.daysBeforeMove = None
		self.maxQuota = None
		self.defaultQuota = None
		self.excludedFolders = None
		pass

class __StoragePolicySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = StoragePolicy()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		daysBeforeMoveValue = value['daysBeforeMove']
		instance.daysBeforeMove = serder.INT.parse(daysBeforeMoveValue)
		maxQuotaValue = value['maxQuota']
		instance.maxQuota = serder.INT.parse(maxQuotaValue)
		defaultQuotaValue = value['defaultQuota']
		instance.defaultQuota = serder.INT.parse(defaultQuotaValue)
		excludedFoldersValue = value['excludedFolders']
		instance.excludedFolders = serder.ListSerDer(serder.STRING).parse(excludedFoldersValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		daysBeforeMoveValue = value.daysBeforeMove
		instance["daysBeforeMove"] = serder.INT.encode(daysBeforeMoveValue)
		maxQuotaValue = value.maxQuota
		instance["maxQuota"] = serder.INT.encode(maxQuotaValue)
		defaultQuotaValue = value.defaultQuota
		instance["defaultQuota"] = serder.INT.encode(defaultQuotaValue)
		excludedFoldersValue = value.excludedFolders
		instance["excludedFolders"] = serder.ListSerDer(serder.STRING).encode(excludedFoldersValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Mailbox :
	def __init__( self):
		self.name = None
		self.system = None
		self.hidden = None
		self.archived = None
		self.type = None
		self.routing = None
		self.emails = None
		self.dataLocation = None
		self.quota = None
		pass

class __MailboxSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Mailbox()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		systemValue = value['system']
		instance.system = serder.BOOLEAN.parse(systemValue)
		hiddenValue = value['hidden']
		instance.hidden = serder.BOOLEAN.parse(hiddenValue)
		archivedValue = value['archived']
		instance.archived = serder.BOOLEAN.parse(archivedValue)
		from netbluemind.mailbox.api.MailboxType import MailboxType
		from netbluemind.mailbox.api.MailboxType import __MailboxTypeSerDer__
		typeValue = value['type']
		instance.type = __MailboxTypeSerDer__().parse(typeValue)
		from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
		from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
		routingValue = value['routing']
		instance.routing = __MailboxRoutingSerDer__().parse(routingValue)
		from netbluemind.core.api.Email import Email
		from netbluemind.core.api.Email import __EmailSerDer__
		emailsValue = value['emails']
		instance.emails = serder.CollectionSerDer(__EmailSerDer__()).parse(emailsValue)
		dataLocationValue = value['dataLocation']
		instance.dataLocation = serder.STRING.parse(dataLocationValue)
		quotaValue = value['quota']
		instance.quota = serder.INT.parse(quotaValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		systemValue = value.system
		instance["system"] = serder.BOOLEAN.encode(systemValue)
		hiddenValue = value.hidden
		instance["hidden"] = serder.BOOLEAN.encode(hiddenValue)
		archivedValue = value.archived
		instance["archived"] = serder.BOOLEAN.encode(archivedValue)
		from netbluemind.mailbox.api.MailboxType import MailboxType
		from netbluemind.mailbox.api.MailboxType import __MailboxTypeSerDer__
		typeValue = value.type
		instance["type"] = __MailboxTypeSerDer__().encode(typeValue)
		from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
		from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
		routingValue = value.routing
		instance["routing"] = __MailboxRoutingSerDer__().encode(routingValue)
		from netbluemind.core.api.Email import Email
		from netbluemind.core.api.Email import __EmailSerDer__
		emailsValue = value.emails
		instance["emails"] = serder.CollectionSerDer(__EmailSerDer__()).encode(emailsValue)
		dataLocationValue = value.dataLocation
		instance["dataLocation"] = serder.STRING.encode(dataLocationValue)
		quotaValue = value.quota
		instance["quota"] = serder.INT.encode(quotaValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IContainerManagement_VERSION = "3.1.28078"

class IContainerManagement(BaseEndpoint):
	def __init__(self, apiKey, url ,containerUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/containers/_manage/{containerUid}'
		self.containerUid_ = containerUid
		self.base = self.base.replace('{containerUid}',containerUid)

	def getDescriptor (self):
		postUri = "/_descriptor";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(__ContainerDescriptorSerDer__(), response)
	def getSettings (self):
		postUri = "/_settings";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.MapSerDer(serder.STRING), response)
	def getAccessControlList (self):
		postUri = "/_acl";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
		from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
		return self.handleResult__(serder.ListSerDer(__AccessControlEntrySerDer__()), response)
	def getAllItems (self):
		postUri = "/_list";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
		from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
	def subscribers (self):
		postUri = "/_subscription";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def getItemCount (self):
		postUri = "/_itemCount";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.api.Count import Count
		from netbluemind.core.container.api.Count import __CountSerDer__
		return self.handleResult__(__CountSerDer__(), response)
	def setAccessControlList (self, entries ):
		postUri = "/_acl";
		__data__ = None
		from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
		from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
		__data__ = serder.ListSerDer(__AccessControlEntrySerDer__()).encode(entries)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def update (self, descriptor ):
		postUri = "/_descriptor";
		__data__ = None
		from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
		from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
		__data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def allowOfflineSync (self, subject ):
		postUri = "/{subject}/offlineSync";
		__data__ = None
		postUri = postUri.replace("{subject}",subject);
		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def setSettings (self, settings ):
		postUri = "/_settings";
		__data__ = None
		__data__ = serder.MapSerDer(serder.STRING).encode(settings)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getItems (self, uids ):
		postUri = "/_mget";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(uids)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
		from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
	def disallowOfflineSync (self, subject ):
		postUri = "/{subject}/offlineSync";
		__data__ = None
		postUri = postUri.replace("{subject}",subject);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def setPersonalSettings (self, settings ):
		postUri = "/_personalSettings";
		__data__ = None
		__data__ = serder.MapSerDer(serder.STRING).encode(settings)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IContainers_VERSION = "3.1.28078"

class IContainers(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/containers/_manage'

	def all (self, query ):
		postUri = "/_list";
		__data__ = None
		from netbluemind.core.container.api.ContainerQuery import ContainerQuery
		from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
		__data__ = __ContainerQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
	def getContainers (self, containerIds ):
		postUri = "/_mget";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(containerIds)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
	def setAccessControlList (self, uid , entries ):
		postUri = "/{uid}/_acl";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
		from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
		__data__ = serder.ListSerDer(__AccessControlEntrySerDer__()).encode(entries)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def update (self, uid , descriptor ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
		from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
		__data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def allLight (self, query ):
		postUri = "/_listLight";
		__data__ = None
		from netbluemind.core.container.api.ContainerQuery import ContainerQuery
		from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
		__data__ = __ContainerQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
		from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
		return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)
	def allForUser (self, domainUid , userUid , query ):
		postUri = "/_listforuser";
		__data__ = None
		from netbluemind.core.container.api.ContainerQuery import ContainerQuery
		from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
		__data__ = __ContainerQuerySerDer__().encode(query)

		queryParams = {  'domainUid': domainUid  , 'userUid': userUid    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def get (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(__ContainerDescriptorSerDer__(), response)
	def create (self, uid , descriptor ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		__data__ = __ContainerDescriptorSerDer__().encode(descriptor)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getIfPresent (self, uid ):
		postUri = "/_ifPresent/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(__ContainerDescriptorSerDer__(), response)
	def getForUser (self, domainUid , userUid , uid ):
		postUri = "/_forUser";
		__data__ = None
		queryParams = {  'domainUid': domainUid  , 'userUid': userUid  , 'uid': uid   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainers_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
		from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
		return self.handleResult__(__ContainerDescriptorSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CommandStatus :
	def __init__( self):
		self.complete = None
		self.successful = None
		self.output = None
		pass

class __CommandStatusSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = CommandStatus()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		completeValue = value['complete']
		instance.complete = serder.BOOLEAN.parse(completeValue)
		successfulValue = value['successful']
		instance.successful = serder.BOOLEAN.parse(successfulValue)
		outputValue = value['output']
		instance.output = serder.CollectionSerDer(serder.STRING).parse(outputValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		completeValue = value.complete
		instance["complete"] = serder.BOOLEAN.encode(completeValue)
		successfulValue = value.successful
		instance["successful"] = serder.BOOLEAN.encode(successfulValue)
		outputValue = value.output
		instance["output"] = serder.CollectionSerDer(serder.STRING).encode(outputValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.addressbook.api.VCardBasicAttribute import VCardBasicAttribute
from netbluemind.addressbook.api.VCardBasicAttribute import __VCardBasicAttributeSerDer__
class VCardDeliveryAddressingAddress (VCardBasicAttribute):
	def __init__( self):
		VCardBasicAttribute.__init__(self)
		self.postOfficeBox = None
		self.extentedAddress = None
		self.streetAddress = None
		self.locality = None
		self.region = None
		self.postalCode = None
		self.countryName = None
		pass

class __VCardDeliveryAddressingAddressSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardDeliveryAddressingAddress()
		__VCardBasicAttributeSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		postOfficeBoxValue = value['postOfficeBox']
		instance.postOfficeBox = serder.STRING.parse(postOfficeBoxValue)
		extentedAddressValue = value['extentedAddress']
		instance.extentedAddress = serder.STRING.parse(extentedAddressValue)
		streetAddressValue = value['streetAddress']
		instance.streetAddress = serder.STRING.parse(streetAddressValue)
		localityValue = value['locality']
		instance.locality = serder.STRING.parse(localityValue)
		regionValue = value['region']
		instance.region = serder.STRING.parse(regionValue)
		postalCodeValue = value['postalCode']
		instance.postalCode = serder.STRING.parse(postalCodeValue)
		countryNameValue = value['countryName']
		instance.countryName = serder.STRING.parse(countryNameValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__VCardBasicAttributeSerDer__().encodeInternal(value,instance)

		postOfficeBoxValue = value.postOfficeBox
		instance["postOfficeBox"] = serder.STRING.encode(postOfficeBoxValue)
		extentedAddressValue = value.extentedAddress
		instance["extentedAddress"] = serder.STRING.encode(extentedAddressValue)
		streetAddressValue = value.streetAddress
		instance["streetAddress"] = serder.STRING.encode(streetAddressValue)
		localityValue = value.locality
		instance["locality"] = serder.STRING.encode(localityValue)
		regionValue = value.region
		instance["region"] = serder.STRING.encode(regionValue)
		postalCodeValue = value.postalCode
		instance["postalCode"] = serder.STRING.encode(postalCodeValue)
		countryNameValue = value.countryName
		instance["countryName"] = serder.STRING.encode(countryNameValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VersionInfo :
	def __init__( self):
		self.major = None
		self.minor = None
		self.release = None
		self.displayName = None
		pass

class __VersionInfoSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VersionInfo()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		majorValue = value['major']
		instance.major = serder.STRING.parse(majorValue)
		minorValue = value['minor']
		instance.minor = serder.STRING.parse(minorValue)
		releaseValue = value['release']
		instance.release = serder.STRING.parse(releaseValue)
		displayNameValue = value['displayName']
		instance.displayName = serder.STRING.parse(displayNameValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		majorValue = value.major
		instance["major"] = serder.STRING.encode(majorValue)
		minorValue = value.minor
		instance["minor"] = serder.STRING.encode(minorValue)
		releaseValue = value.release
		instance["release"] = serder.STRING.encode(releaseValue)
		displayNameValue = value.displayName
		instance["displayName"] = serder.STRING.encode(displayNameValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.directory.api.DirBaseValue import DirBaseValue
from netbluemind.directory.api.DirBaseValue import __DirBaseValueSerDer__
class Mailshare (DirBaseValue):
	def __init__( self):
		DirBaseValue.__init__(self)
		self.name = None
		self.quota = None
		self.routing = None
		self.card = None
		pass

class __MailshareSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Mailshare()
		__DirBaseValueSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		quotaValue = value['quota']
		instance.quota = serder.INT.parse(quotaValue)
		from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
		from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
		routingValue = value['routing']
		instance.routing = __MailboxRoutingSerDer__().parse(routingValue)
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		cardValue = value['card']
		instance.card = __VCardSerDer__().parse(cardValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__DirBaseValueSerDer__().encodeInternal(value,instance)

		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		quotaValue = value.quota
		instance["quota"] = serder.INT.encode(quotaValue)
		from netbluemind.mailbox.api.MailboxRouting import MailboxRouting
		from netbluemind.mailbox.api.MailboxRouting import __MailboxRoutingSerDer__
		routingValue = value.routing
		instance["routing"] = __MailboxRoutingSerDer__().encode(routingValue)
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		cardValue = value.card
		instance["card"] = __VCardSerDer__().encode(cardValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ContainerSyncStatus :
	def __init__( self):
		self.syncToken = None
		self.nextSync = None
		self.lastSync = None
		self.syncStatus = None
		pass

class __ContainerSyncStatusSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ContainerSyncStatus()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		syncTokenValue = value['syncToken']
		instance.syncToken = serder.STRING.parse(syncTokenValue)
		nextSyncValue = value['nextSync']
		instance.nextSync = serder.LONG.parse(nextSyncValue)
		lastSyncValue = value['lastSync']
		instance.lastSync = serder.DATE.parse(lastSyncValue)
		from netbluemind.core.container.model.ContainerSyncStatusStatus import ContainerSyncStatusStatus
		from netbluemind.core.container.model.ContainerSyncStatusStatus import __ContainerSyncStatusStatusSerDer__
		syncStatusValue = value['syncStatus']
		instance.syncStatus = __ContainerSyncStatusStatusSerDer__().parse(syncStatusValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		syncTokenValue = value.syncToken
		instance["syncToken"] = serder.STRING.encode(syncTokenValue)
		nextSyncValue = value.nextSync
		instance["nextSync"] = serder.LONG.encode(nextSyncValue)
		lastSyncValue = value.lastSync
		instance["lastSync"] = serder.DATE.encode(lastSyncValue)
		from netbluemind.core.container.model.ContainerSyncStatusStatus import ContainerSyncStatusStatus
		from netbluemind.core.container.model.ContainerSyncStatusStatus import __ContainerSyncStatusStatusSerDer__
		syncStatusValue = value.syncStatus
		instance["syncStatus"] = __ContainerSyncStatusStatusSerDer__().encode(syncStatusValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class PartGeneration :
	def __init__( self):
		self.id = None
		self.generationId = None
		self.begin = None
		self.end = None
		self.size = None
		self.tag = None
		self.server = None
		self.withWarnings = None
		self.withErrors = None
		self.valid = None
		pass

class __PartGenerationSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = PartGeneration()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		idValue = value['id']
		instance.id = serder.INT.parse(idValue)
		generationIdValue = value['generationId']
		instance.generationId = serder.INT.parse(generationIdValue)
		beginValue = value['begin']
		instance.begin = serder.DATE.parse(beginValue)
		endValue = value['end']
		instance.end = serder.DATE.parse(endValue)
		sizeValue = value['size']
		instance.size = serder.LONG.parse(sizeValue)
		tagValue = value['tag']
		instance.tag = serder.STRING.parse(tagValue)
		serverValue = value['server']
		instance.server = serder.STRING.parse(serverValue)
		withWarningsValue = value['withWarnings']
		instance.withWarnings = serder.BOOLEAN.parse(withWarningsValue)
		withErrorsValue = value['withErrors']
		instance.withErrors = serder.BOOLEAN.parse(withErrorsValue)
		from netbluemind.dataprotect.api.GenerationStatus import GenerationStatus
		from netbluemind.dataprotect.api.GenerationStatus import __GenerationStatusSerDer__
		validValue = value['valid']
		instance.valid = __GenerationStatusSerDer__().parse(validValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		idValue = value.id
		instance["id"] = serder.INT.encode(idValue)
		generationIdValue = value.generationId
		instance["generationId"] = serder.INT.encode(generationIdValue)
		beginValue = value.begin
		instance["begin"] = serder.DATE.encode(beginValue)
		endValue = value.end
		instance["end"] = serder.DATE.encode(endValue)
		sizeValue = value.size
		instance["size"] = serder.LONG.encode(sizeValue)
		tagValue = value.tag
		instance["tag"] = serder.STRING.encode(tagValue)
		serverValue = value.server
		instance["server"] = serder.STRING.encode(serverValue)
		withWarningsValue = value.withWarnings
		instance["withWarnings"] = serder.BOOLEAN.encode(withWarningsValue)
		withErrorsValue = value.withErrors
		instance["withErrors"] = serder.BOOLEAN.encode(withErrorsValue)
		from netbluemind.dataprotect.api.GenerationStatus import GenerationStatus
		from netbluemind.dataprotect.api.GenerationStatus import __GenerationStatusSerDer__
		validValue = value.valid
		instance["valid"] = __GenerationStatusSerDer__().encode(validValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IServer_VERSION = "3.1.28078"

class IServer(BaseEndpoint):
	def __init__(self, apiKey, url ,containerUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/servers/{containerUid}'
		self.containerUid_ = containerUid
		self.base = self.base.replace('{containerUid}',containerUid)

	def submit (self, uid , command ):
		postUri = "/{uid}/submit_command";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.STRING.encode(command)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.STRING, response)
	def update (self, uid , srv ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.server.api.Server import Server
		from netbluemind.server.api.Server import __ServerSerDer__
		__data__ = __ServerSerDer__().encode(srv)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def getAssignments (self, domainUid ):
		postUri = "/{domainUid}/assignments";
		__data__ = None
		postUri = postUri.replace("{domainUid}",domainUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.server.api.Assignment import Assignment
		from netbluemind.server.api.Assignment import __AssignmentSerDer__
		return self.handleResult__(serder.ListSerDer(__AssignmentSerDer__()), response)
	def setTags (self, uid , tags ):
		postUri = "/{uid}/tags";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.ListSerDer(serder.STRING).encode(tags)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def getStatus (self, uid , ref ):
		postUri = "/{uid}/command_status";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   'ref': ref   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.server.api.CommandStatus import CommandStatus
		from netbluemind.server.api.CommandStatus import __CommandStatusSerDer__
		return self.handleResult__(__CommandStatusSerDer__(), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def byAssignment (self, domainUid , tag ):
		postUri = "/{domainUid}/byAssignment";
		__data__ = None
		postUri = postUri.replace("{domainUid}",domainUid);
		queryParams = {   'tag': tag   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def create (self, uid , srv ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.server.api.Server import Server
		from netbluemind.server.api.Server import __ServerSerDer__
		__data__ = __ServerSerDer__().encode(srv)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def allComplete (self):
		postUri = "/_complete";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.server.api.Server import Server
		from netbluemind.server.api.Server import __ServerSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__ServerSerDer__())), response)
	def writeFile (self, uid , path , content ):
		postUri = "/{uid}/fs/{path}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		postUri = postUri.replace("{path}",path);
		__data__ = serder.ByteArraySerDer.encode(content)

		queryParams = {     };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def unassign (self, serverUid , domainUid , tag ):
		postUri = "/{domainUid}/assignments/{serverUid}/_unassign";
		__data__ = None
		postUri = postUri.replace("{serverUid}",serverUid);
		postUri = postUri.replace("{domainUid}",domainUid);
		queryParams = {    'tag': tag   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.server.api.Server import Server
		from netbluemind.server.api.Server import __ServerSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__ServerSerDer__()), response)
	def getServerAssignments (self, uid ):
		postUri = "/{uid}/serverAssignments";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.server.api.Assignment import Assignment
		from netbluemind.server.api.Assignment import __AssignmentSerDer__
		return self.handleResult__(serder.ListSerDer(__AssignmentSerDer__()), response)
	def readFile (self, uid , path ):
		postUri = "/{uid}/fs/{path}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		postUri = postUri.replace("{path}",path);
		queryParams = {    };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def submitAndWait (self, uid , command ):
		postUri = "/{uid}/submit_command_and_wait";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.STRING.encode(command)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		from netbluemind.server.api.CommandStatus import CommandStatus
		from netbluemind.server.api.CommandStatus import __CommandStatusSerDer__
		return self.handleResult__(__CommandStatusSerDer__(), response)
	def assign (self, serverUid , domainUid , tag ):
		postUri = "/{domainUid}/assignments/{serverUid}/_assign";
		__data__ = None
		postUri = postUri.replace("{serverUid}",serverUid);
		postUri = postUri.replace("{domainUid}",domainUid);
		queryParams = {    'tag': tag   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IServer_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class FileHostingInfo :
	def __init__( self):
		self.present = None
		self.info = None
		pass

class __FileHostingInfoSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = FileHostingInfo()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		presentValue = value['present']
		instance.present = serder.BOOLEAN.parse(presentValue)
		infoValue = value['info']
		instance.info = serder.STRING.parse(infoValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		presentValue = value.present
		instance["present"] = serder.BOOLEAN.encode(presentValue)
		infoValue = value.info
		instance["info"] = serder.STRING.encode(infoValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Domain :
	def __init__( self):
		self.label = None
		self.name = None
		self.description = None
		self.properties = None
		self.global_ = None
		self.aliases = None
		pass

class __DomainSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Domain()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		labelValue = value['label']
		instance.label = serder.STRING.parse(labelValue)
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		propertiesValue = value['properties']
		instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
		global_Value = value['global']
		instance.global_ = serder.BOOLEAN.parse(global_Value)
		aliasesValue = value['aliases']
		instance.aliases = serder.SetSerDer(serder.STRING).parse(aliasesValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		labelValue = value.label
		instance["label"] = serder.STRING.encode(labelValue)
		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		propertiesValue = value.properties
		instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
		global_Value = value.global_
		instance["global"] = serder.BOOLEAN.encode(global_Value)
		aliasesValue = value.aliases
		instance["aliases"] = serder.SetSerDer(serder.STRING).encode(aliasesValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDirectory_VERSION = "3.1.28078"

class IDirectory(BaseEndpoint):
	def __init__(self, apiKey, url ,domain ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/directory/{domain}'
		self.domain_ = domain
		self.base = self.base.replace('{domain}',domain)

	def getEntryIcon (self, entryUid ):
		postUri = "/entry-uid/{entryUid}/icon";
		__data__ = None
		postUri = postUri.replace("{entryUid}",entryUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def getVCard (self, uid ):
		postUri = "/{uid}/_vcard";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.addressbook.api.VCard import VCard
		from netbluemind.addressbook.api.VCard import __VCardSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
	def delete (self, path ):
		postUri = "/{path}";
		__data__ = None
		postUri = postUri.replace("{path}",path);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def changeset (self, since ):
		postUri = "/_changeset";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
	def search (self, query ):
		postUri = "/_search";
		__data__ = None
		from netbluemind.directory.api.DirEntryQuery import DirEntryQuery
		from netbluemind.directory.api.DirEntryQuery import __DirEntryQuerySerDer__
		__data__ = __DirEntryQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		from netbluemind.core.api.ListResult import ListResult
		from netbluemind.core.api.ListResult import __ListResultSerDer__
		return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__DirEntrySerDer__())), response)
	def findByEntryUid (self, entryUid ):
		postUri = "/entry-uid/{entryUid}";
		__data__ = None
		postUri = postUri.replace("{entryUid}",entryUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		return self.handleResult__(__DirEntrySerDer__(), response)
	def getEntryPhoto (self, entryUid ):
		postUri = "/entry-uid/{entryUid}/photo";
		__data__ = None
		postUri = postUri.replace("{entryUid}",entryUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def getEntry (self, path ):
		postUri = "/_entry";
		__data__ = None
		__data__ = serder.STRING.encode(path)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		return self.handleResult__(__DirEntrySerDer__(), response)
	def getRoot (self):
		postUri = "";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		return self.handleResult__(__DirEntrySerDer__(), response)
	def deleteByEntryUid (self, entryUid ):
		postUri = "/_byentryuid/{entryUid}";
		__data__ = None
		postUri = postUri.replace("{entryUid}",entryUid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getByEmail (self, email ):
		postUri = "/_byEmail/{email}";
		__data__ = None
		postUri = postUri.replace("{email}",email);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		return self.handleResult__(__DirEntrySerDer__(), response)
	def getRolesForDirEntry (self, entryUid ):
		postUri = "/entry-uid/{entryUid}/rolesfor_";
		__data__ = None
		postUri = postUri.replace("{entryUid}",entryUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def changelog (self, since ):
		postUri = "/_changelog";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
		from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
		return self.handleResult__(__ContainerChangelogSerDer__(), response)
	def getRolesForOrgUnit (self, ouUid ):
		postUri = "/ou-uid/{ouUid}/rolesfor_";
		__data__ = None
		postUri = postUri.replace("{ouUid}",ouUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.SetSerDer(serder.STRING), response)
	def getIcon (self, path ):
		postUri = "/_icon/{path}";
		__data__ = None
		postUri = postUri.replace("{path}",path);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def getEntries (self, path ):
		postUri = "/_childs";
		__data__ = None
		__data__ = serder.STRING.encode(path)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = json.dumps(__data__));
		from netbluemind.directory.api.DirEntry import DirEntry
		from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
		return self.handleResult__(serder.ListSerDer(__DirEntrySerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardCommunications :
	def __init__( self):
		self.tels = None
		self.emails = None
		self.impps = None
		self.langs = None
		pass

class __VCardCommunicationsSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VCardCommunications()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.addressbook.api.VCardCommunicationsTel import VCardCommunicationsTel
		from netbluemind.addressbook.api.VCardCommunicationsTel import __VCardCommunicationsTelSerDer__
		telsValue = value['tels']
		instance.tels = serder.ListSerDer(__VCardCommunicationsTelSerDer__()).parse(telsValue)
		from netbluemind.addressbook.api.VCardCommunicationsEmail import VCardCommunicationsEmail
		from netbluemind.addressbook.api.VCardCommunicationsEmail import __VCardCommunicationsEmailSerDer__
		emailsValue = value['emails']
		instance.emails = serder.ListSerDer(__VCardCommunicationsEmailSerDer__()).parse(emailsValue)
		from netbluemind.addressbook.api.VCardCommunicationsImpp import VCardCommunicationsImpp
		from netbluemind.addressbook.api.VCardCommunicationsImpp import __VCardCommunicationsImppSerDer__
		imppsValue = value['impps']
		instance.impps = serder.ListSerDer(__VCardCommunicationsImppSerDer__()).parse(imppsValue)
		from netbluemind.addressbook.api.VCardCommunicationsLang import VCardCommunicationsLang
		from netbluemind.addressbook.api.VCardCommunicationsLang import __VCardCommunicationsLangSerDer__
		langsValue = value['langs']
		instance.langs = serder.ListSerDer(__VCardCommunicationsLangSerDer__()).parse(langsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.addressbook.api.VCardCommunicationsTel import VCardCommunicationsTel
		from netbluemind.addressbook.api.VCardCommunicationsTel import __VCardCommunicationsTelSerDer__
		telsValue = value.tels
		instance["tels"] = serder.ListSerDer(__VCardCommunicationsTelSerDer__()).encode(telsValue)
		from netbluemind.addressbook.api.VCardCommunicationsEmail import VCardCommunicationsEmail
		from netbluemind.addressbook.api.VCardCommunicationsEmail import __VCardCommunicationsEmailSerDer__
		emailsValue = value.emails
		instance["emails"] = serder.ListSerDer(__VCardCommunicationsEmailSerDer__()).encode(emailsValue)
		from netbluemind.addressbook.api.VCardCommunicationsImpp import VCardCommunicationsImpp
		from netbluemind.addressbook.api.VCardCommunicationsImpp import __VCardCommunicationsImppSerDer__
		imppsValue = value.impps
		instance["impps"] = serder.ListSerDer(__VCardCommunicationsImppSerDer__()).encode(imppsValue)
		from netbluemind.addressbook.api.VCardCommunicationsLang import VCardCommunicationsLang
		from netbluemind.addressbook.api.VCardCommunicationsLang import __VCardCommunicationsLangSerDer__
		langsValue = value.langs
		instance["langs"] = serder.ListSerDer(__VCardCommunicationsLangSerDer__()).encode(langsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class RoleDescriptor :
	def __init__( self):
		self.id = None
		self.parentRoleId = None
		self.categoryId = None
		self.label = None
		self.description = None
		self.selfPromote = None
		self.dirEntryPromote = None
		self.dirEntryKind = None
		self.siblingRole = None
		self.childsRole = None
		self.visible = None
		self.delegable = None
		self.containerRoles = None
		self.priority = None
		pass

class __RoleDescriptorSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = RoleDescriptor()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		idValue = value['id']
		instance.id = serder.STRING.parse(idValue)
		parentRoleIdValue = value['parentRoleId']
		instance.parentRoleId = serder.STRING.parse(parentRoleIdValue)
		categoryIdValue = value['categoryId']
		instance.categoryId = serder.STRING.parse(categoryIdValue)
		labelValue = value['label']
		instance.label = serder.STRING.parse(labelValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		selfPromoteValue = value['selfPromote']
		instance.selfPromote = serder.BOOLEAN.parse(selfPromoteValue)
		dirEntryPromoteValue = value['dirEntryPromote']
		instance.dirEntryPromote = serder.BOOLEAN.parse(dirEntryPromoteValue)
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		dirEntryKindValue = value['dirEntryKind']
		instance.dirEntryKind = __DirEntryKindSerDer__().parse(dirEntryKindValue)
		siblingRoleValue = value['siblingRole']
		instance.siblingRole = serder.STRING.parse(siblingRoleValue)
		childsRoleValue = value['childsRole']
		instance.childsRole = serder.SetSerDer(serder.STRING).parse(childsRoleValue)
		visibleValue = value['visible']
		instance.visible = serder.BOOLEAN.parse(visibleValue)
		delegableValue = value['delegable']
		instance.delegable = serder.BOOLEAN.parse(delegableValue)
		containerRolesValue = value['containerRoles']
		instance.containerRoles = serder.SetSerDer(serder.STRING).parse(containerRolesValue)
		priorityValue = value['priority']
		instance.priority = serder.INT.parse(priorityValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		idValue = value.id
		instance["id"] = serder.STRING.encode(idValue)
		parentRoleIdValue = value.parentRoleId
		instance["parentRoleId"] = serder.STRING.encode(parentRoleIdValue)
		categoryIdValue = value.categoryId
		instance["categoryId"] = serder.STRING.encode(categoryIdValue)
		labelValue = value.label
		instance["label"] = serder.STRING.encode(labelValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		selfPromoteValue = value.selfPromote
		instance["selfPromote"] = serder.BOOLEAN.encode(selfPromoteValue)
		dirEntryPromoteValue = value.dirEntryPromote
		instance["dirEntryPromote"] = serder.BOOLEAN.encode(dirEntryPromoteValue)
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		dirEntryKindValue = value.dirEntryKind
		instance["dirEntryKind"] = __DirEntryKindSerDer__().encode(dirEntryKindValue)
		siblingRoleValue = value.siblingRole
		instance["siblingRole"] = serder.STRING.encode(siblingRoleValue)
		childsRoleValue = value.childsRole
		instance["childsRole"] = serder.SetSerDer(serder.STRING).encode(childsRoleValue)
		visibleValue = value.visible
		instance["visible"] = serder.BOOLEAN.encode(visibleValue)
		delegableValue = value.delegable
		instance["delegable"] = serder.BOOLEAN.encode(delegableValue)
		containerRolesValue = value.containerRoles
		instance["containerRoles"] = serder.SetSerDer(serder.STRING).encode(containerRolesValue)
		priorityValue = value.priority
		instance["priority"] = serder.INT.encode(priorityValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ShardStats :
	def __init__( self):
		self.indexName = None
		self.mailboxes = None
		self.topMailbox = None
		self.docCount = None
		self.state = None
		self.size = None
		pass

class __ShardStatsSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ShardStats()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		indexNameValue = value['indexName']
		instance.indexName = serder.STRING.parse(indexNameValue)
		mailboxesValue = value['mailboxes']
		instance.mailboxes = serder.SetSerDer(serder.STRING).parse(mailboxesValue)
		from netbluemind.mailbox.api.ShardStatsMailboxStats import ShardStatsMailboxStats
		from netbluemind.mailbox.api.ShardStatsMailboxStats import __ShardStatsMailboxStatsSerDer__
		topMailboxValue = value['topMailbox']
		instance.topMailbox = serder.ListSerDer(__ShardStatsMailboxStatsSerDer__()).parse(topMailboxValue)
		docCountValue = value['docCount']
		instance.docCount = serder.LONG.parse(docCountValue)
		from netbluemind.mailbox.api.ShardStatsState import ShardStatsState
		from netbluemind.mailbox.api.ShardStatsState import __ShardStatsStateSerDer__
		stateValue = value['state']
		instance.state = __ShardStatsStateSerDer__().parse(stateValue)
		sizeValue = value['size']
		instance.size = serder.LONG.parse(sizeValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		indexNameValue = value.indexName
		instance["indexName"] = serder.STRING.encode(indexNameValue)
		mailboxesValue = value.mailboxes
		instance["mailboxes"] = serder.SetSerDer(serder.STRING).encode(mailboxesValue)
		from netbluemind.mailbox.api.ShardStatsMailboxStats import ShardStatsMailboxStats
		from netbluemind.mailbox.api.ShardStatsMailboxStats import __ShardStatsMailboxStatsSerDer__
		topMailboxValue = value.topMailbox
		instance["topMailbox"] = serder.ListSerDer(__ShardStatsMailboxStatsSerDer__()).encode(topMailboxValue)
		docCountValue = value.docCount
		instance["docCount"] = serder.LONG.encode(docCountValue)
		from netbluemind.mailbox.api.ShardStatsState import ShardStatsState
		from netbluemind.mailbox.api.ShardStatsState import __ShardStatsStateSerDer__
		stateValue = value.state
		instance["state"] = __ShardStatsStateSerDer__().encode(stateValue)
		sizeValue = value.size
		instance["size"] = serder.LONG.encode(sizeValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class JobPlanification :
	def __init__( self):
		self.kind = None
		self.rec = None
		self.lastRun = None
		self.nextRun = None
		self.domain = None
		pass

class __JobPlanificationSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = JobPlanification()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.scheduledjob.api.PlanKind import PlanKind
		from netbluemind.scheduledjob.api.PlanKind import __PlanKindSerDer__
		kindValue = value['kind']
		instance.kind = __PlanKindSerDer__().parse(kindValue)
		from netbluemind.scheduledjob.api.JobRec import JobRec
		from netbluemind.scheduledjob.api.JobRec import __JobRecSerDer__
		recValue = value['rec']
		instance.rec = __JobRecSerDer__().parse(recValue)
		lastRunValue = value['lastRun']
		instance.lastRun = serder.DATE.parse(lastRunValue)
		nextRunValue = value['nextRun']
		instance.nextRun = serder.DATE.parse(nextRunValue)
		domainValue = value['domain']
		instance.domain = serder.STRING.parse(domainValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.scheduledjob.api.PlanKind import PlanKind
		from netbluemind.scheduledjob.api.PlanKind import __PlanKindSerDer__
		kindValue = value.kind
		instance["kind"] = __PlanKindSerDer__().encode(kindValue)
		from netbluemind.scheduledjob.api.JobRec import JobRec
		from netbluemind.scheduledjob.api.JobRec import __JobRecSerDer__
		recValue = value.rec
		instance["rec"] = __JobRecSerDer__().encode(recValue)
		lastRunValue = value.lastRun
		instance["lastRun"] = serder.DATE.encode(lastRunValue)
		nextRunValue = value.nextRun
		instance["nextRun"] = serder.DATE.encode(nextRunValue)
		domainValue = value.domain
		instance["domain"] = serder.STRING.encode(domainValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementRRuleWeekDay :
	def __init__( self):
		self.day = None
		self.offset = None
		pass

class __ICalendarElementRRuleWeekDaySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementRRuleWeekDay()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		dayValue = value['day']
		instance.day = serder.STRING.parse(dayValue)
		offsetValue = value['offset']
		instance.offset = serder.INT.parse(offsetValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		dayValue = value.day
		instance["day"] = serder.STRING.encode(dayValue)
		offsetValue = value.offset
		instance["offset"] = serder.INT.encode(offsetValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ITodoList_VERSION = "3.1.28078"

class ITodoList(BaseEndpoint):
	def __init__(self, apiKey, url ,containerUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/todolist/{containerUid}'
		self.containerUid_ = containerUid
		self.base = self.base.replace('{containerUid}',containerUid)

	def allUids (self):
		postUri = "/_all";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def update (self, uid , todo ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		__data__ = __VTodoSerDer__().encode(todo)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def updates (self, changes ):
		postUri = "/_mupdates";
		__data__ = None
		from netbluemind.todolist.api.VTodoChanges import VTodoChanges
		from netbluemind.todolist.api.VTodoChanges import __VTodoChangesSerDer__
		__data__ = __VTodoChangesSerDer__().encode(changes)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
		from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
		return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def changeset (self, since ):
		postUri = "/_changeset";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
	def changesetById (self, since ):
		postUri = "/_changesetById";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
	def search (self, query ):
		postUri = "/_search";
		__data__ = None
		from netbluemind.todolist.api.VTodoQuery import VTodoQuery
		from netbluemind.todolist.api.VTodoQuery import __VTodoQuerySerDer__
		__data__ = __VTodoQuerySerDer__().encode(query)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		from netbluemind.core.api.ListResult import ListResult
		from netbluemind.core.api.ListResult import __ListResultSerDer__
		return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__VTodoSerDer__())), response)
	def getReminder (self, dtalarm ):
		postUri = "/_remimder";
		__data__ = None
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		__data__ = __BmDateTimeSerDer__().encode(dtalarm)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.todolist.api.Reminder import Reminder
		from netbluemind.todolist.api.Reminder import __ReminderSerDer__
		return self.handleResult__(serder.ListSerDer(__ReminderSerDer__()), response)
	def create (self, uid , todo ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		__data__ = __VTodoSerDer__().encode(todo)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def copy (self, uids , destContainerUid ):
		postUri = "/_copy/{destContainerUid}";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(uids)

		postUri = postUri.replace("{destContainerUid}",destContainerUid);
		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def all (self):
		postUri = "";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
	def getVersion (self):
		postUri = "/_version";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.LONG, response)
	def move (self, uids , destContainerUid ):
		postUri = "/_move/{destContainerUid}";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(uids)

		postUri = postUri.replace("{destContainerUid}",destContainerUid);
		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def multipleGet (self, uids ):
		postUri = "/_mget";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(uids)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VTodoSerDer__())), response)
	def sync (self, since , changes ):
		postUri = "/_sync";
		__data__ = None
		from netbluemind.todolist.api.VTodoChanges import VTodoChanges
		from netbluemind.todolist.api.VTodoChanges import __VTodoChangesSerDer__
		__data__ = __VTodoChangesSerDer__().encode(changes)

		queryParams = {  'since': since    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
	def itemChangelog (self, uid , arg1 ):
		postUri = "/{uid}/_itemchangelog";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.LONG.encode(arg1)

		queryParams = {    };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ItemChangelog import ItemChangelog
		from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
		return self.handleResult__(__ItemChangelogSerDer__(), response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.todolist.api.VTodo import VTodo
		from netbluemind.todolist.api.VTodo import __VTodoSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__VTodoSerDer__()), response)
	def containerChangelog (self, arg0 ):
		postUri = "/_changelog";
		__data__ = None
		__data__ = serder.LONG.encode(arg0)

		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
		from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
		return self.handleResult__(__ContainerChangelogSerDer__(), response)
	def reset (self):
		postUri = "/_reset";
		__data__ = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITodoList_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementVAlarm :
	def __init__( self):
		self.action = None
		self.trigger = None
		self.description = None
		self.duration = None
		self.repeat = None
		self.summary = None
		pass

class __ICalendarElementVAlarmSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementVAlarm()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.icalendar.api.ICalendarElementVAlarmAction import ICalendarElementVAlarmAction
		from netbluemind.icalendar.api.ICalendarElementVAlarmAction import __ICalendarElementVAlarmActionSerDer__
		actionValue = value['action']
		instance.action = __ICalendarElementVAlarmActionSerDer__().parse(actionValue)
		triggerValue = value['trigger']
		instance.trigger = serder.INT.parse(triggerValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		durationValue = value['duration']
		instance.duration = serder.INT.parse(durationValue)
		repeatValue = value['repeat']
		instance.repeat = serder.INT.parse(repeatValue)
		summaryValue = value['summary']
		instance.summary = serder.STRING.parse(summaryValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.icalendar.api.ICalendarElementVAlarmAction import ICalendarElementVAlarmAction
		from netbluemind.icalendar.api.ICalendarElementVAlarmAction import __ICalendarElementVAlarmActionSerDer__
		actionValue = value.action
		instance["action"] = __ICalendarElementVAlarmActionSerDer__().encode(actionValue)
		triggerValue = value.trigger
		instance["trigger"] = serder.INT.encode(triggerValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		durationValue = value.duration
		instance["duration"] = serder.INT.encode(durationValue)
		repeatValue = value.repeat
		instance["repeat"] = serder.INT.encode(repeatValue)
		summaryValue = value.summary
		instance["summary"] = serder.STRING.encode(summaryValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ChangeLogEntry :
	def __init__( self):
		self.version = None
		self.itemUid = None
		self.itemExtId = None
		self.author = None
		self.type = None
		self.date = None
		self.origin = None
		self.internalId = None
		pass

class __ChangeLogEntrySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ChangeLogEntry()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		versionValue = value['version']
		instance.version = serder.LONG.parse(versionValue)
		itemUidValue = value['itemUid']
		instance.itemUid = serder.STRING.parse(itemUidValue)
		itemExtIdValue = value['itemExtId']
		instance.itemExtId = serder.STRING.parse(itemExtIdValue)
		authorValue = value['author']
		instance.author = serder.STRING.parse(authorValue)
		from netbluemind.core.container.model.ChangeLogEntryType import ChangeLogEntryType
		from netbluemind.core.container.model.ChangeLogEntryType import __ChangeLogEntryTypeSerDer__
		typeValue = value['type']
		instance.type = __ChangeLogEntryTypeSerDer__().parse(typeValue)
		dateValue = value['date']
		instance.date = serder.DATE.parse(dateValue)
		originValue = value['origin']
		instance.origin = serder.STRING.parse(originValue)
		internalIdValue = value['internalId']
		instance.internalId = serder.LONG.parse(internalIdValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		versionValue = value.version
		instance["version"] = serder.LONG.encode(versionValue)
		itemUidValue = value.itemUid
		instance["itemUid"] = serder.STRING.encode(itemUidValue)
		itemExtIdValue = value.itemExtId
		instance["itemExtId"] = serder.STRING.encode(itemExtIdValue)
		authorValue = value.author
		instance["author"] = serder.STRING.encode(authorValue)
		from netbluemind.core.container.model.ChangeLogEntryType import ChangeLogEntryType
		from netbluemind.core.container.model.ChangeLogEntryType import __ChangeLogEntryTypeSerDer__
		typeValue = value.type
		instance["type"] = __ChangeLogEntryTypeSerDer__().encode(typeValue)
		dateValue = value.date
		instance["date"] = serder.DATE.encode(dateValue)
		originValue = value.origin
		instance["origin"] = serder.STRING.encode(originValue)
		internalIdValue = value.internalId
		instance["internalId"] = serder.LONG.encode(internalIdValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VEventSeries :
	def __init__( self):
		self.main = None
		self.occurrences = None
		self.properties = None
		self.icsUid = None
		pass

class __VEventSeriesSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VEventSeries()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.calendar.api.VEvent import VEvent
		from netbluemind.calendar.api.VEvent import __VEventSerDer__
		mainValue = value['main']
		instance.main = __VEventSerDer__().parse(mainValue)
		from netbluemind.calendar.api.VEventOccurrence import VEventOccurrence
		from netbluemind.calendar.api.VEventOccurrence import __VEventOccurrenceSerDer__
		occurrencesValue = value['occurrences']
		instance.occurrences = serder.ListSerDer(__VEventOccurrenceSerDer__()).parse(occurrencesValue)
		propertiesValue = value['properties']
		instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
		icsUidValue = value['icsUid']
		instance.icsUid = serder.STRING.parse(icsUidValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.calendar.api.VEvent import VEvent
		from netbluemind.calendar.api.VEvent import __VEventSerDer__
		mainValue = value.main
		instance["main"] = __VEventSerDer__().encode(mainValue)
		from netbluemind.calendar.api.VEventOccurrence import VEventOccurrence
		from netbluemind.calendar.api.VEventOccurrence import __VEventOccurrenceSerDer__
		occurrencesValue = value.occurrences
		instance["occurrences"] = serder.ListSerDer(__VEventOccurrenceSerDer__()).encode(occurrencesValue)
		propertiesValue = value.properties
		instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
		icsUidValue = value.icsUid
		instance["icsUid"] = serder.STRING.encode(icsUidValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class LoginResponse :
	def __init__( self):
		self.status = None
		self.message = None
		self.authKey = None
		self.latd = None
		self.authUser = None
		pass

class __LoginResponseSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = LoginResponse()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.authentication.api.LoginResponseStatus import LoginResponseStatus
		from netbluemind.authentication.api.LoginResponseStatus import __LoginResponseStatusSerDer__
		statusValue = value['status']
		instance.status = __LoginResponseStatusSerDer__().parse(statusValue)
		messageValue = value['message']
		instance.message = serder.STRING.parse(messageValue)
		authKeyValue = value['authKey']
		instance.authKey = serder.STRING.parse(authKeyValue)
		latdValue = value['latd']
		instance.latd = serder.STRING.parse(latdValue)
		from netbluemind.authentication.api.AuthUser import AuthUser
		from netbluemind.authentication.api.AuthUser import __AuthUserSerDer__
		authUserValue = value['authUser']
		instance.authUser = __AuthUserSerDer__().parse(authUserValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.authentication.api.LoginResponseStatus import LoginResponseStatus
		from netbluemind.authentication.api.LoginResponseStatus import __LoginResponseStatusSerDer__
		statusValue = value.status
		instance["status"] = __LoginResponseStatusSerDer__().encode(statusValue)
		messageValue = value.message
		instance["message"] = serder.STRING.encode(messageValue)
		authKeyValue = value.authKey
		instance["authKey"] = serder.STRING.encode(authKeyValue)
		latdValue = value.latd
		instance["latd"] = serder.STRING.encode(latdValue)
		from netbluemind.authentication.api.AuthUser import AuthUser
		from netbluemind.authentication.api.AuthUser import __AuthUserSerDer__
		authUserValue = value.authUser
		instance["authUser"] = __AuthUserSerDer__().encode(authUserValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElement :
	def __init__( self):
		self.dtstart = None
		self.summary = None
		self.classification = None
		self.location = None
		self.description = None
		self.priority = None
		self.alarm = None
		self.status = None
		self.attendees = None
		self.organizer = None
		self.categories = None
		self.exdate = None
		self.rdate = None
		self.rrule = None
		self.url = None
		pass

class __ICalendarElementSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElement()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtstartValue = value['dtstart']
		instance.dtstart = __BmDateTimeSerDer__().parse(dtstartValue)
		summaryValue = value['summary']
		instance.summary = serder.STRING.parse(summaryValue)
		from netbluemind.icalendar.api.ICalendarElementClassification import ICalendarElementClassification
		from netbluemind.icalendar.api.ICalendarElementClassification import __ICalendarElementClassificationSerDer__
		classificationValue = value['classification']
		instance.classification = __ICalendarElementClassificationSerDer__().parse(classificationValue)
		locationValue = value['location']
		instance.location = serder.STRING.parse(locationValue)
		descriptionValue = value['description']
		instance.description = serder.STRING.parse(descriptionValue)
		priorityValue = value['priority']
		instance.priority = serder.INT.parse(priorityValue)
		from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
		from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
		alarmValue = value['alarm']
		instance.alarm = serder.ListSerDer(__ICalendarElementVAlarmSerDer__()).parse(alarmValue)
		from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
		from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
		statusValue = value['status']
		instance.status = __ICalendarElementStatusSerDer__().parse(statusValue)
		from netbluemind.icalendar.api.ICalendarElementAttendee import ICalendarElementAttendee
		from netbluemind.icalendar.api.ICalendarElementAttendee import __ICalendarElementAttendeeSerDer__
		attendeesValue = value['attendees']
		instance.attendees = serder.ListSerDer(__ICalendarElementAttendeeSerDer__()).parse(attendeesValue)
		from netbluemind.icalendar.api.ICalendarElementOrganizer import ICalendarElementOrganizer
		from netbluemind.icalendar.api.ICalendarElementOrganizer import __ICalendarElementOrganizerSerDer__
		organizerValue = value['organizer']
		instance.organizer = __ICalendarElementOrganizerSerDer__().parse(organizerValue)
		from netbluemind.tag.api.TagRef import TagRef
		from netbluemind.tag.api.TagRef import __TagRefSerDer__
		categoriesValue = value['categories']
		instance.categories = serder.ListSerDer(__TagRefSerDer__()).parse(categoriesValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		exdateValue = value['exdate']
		instance.exdate = serder.SetSerDer(__BmDateTimeSerDer__()).parse(exdateValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		rdateValue = value['rdate']
		instance.rdate = serder.SetSerDer(__BmDateTimeSerDer__()).parse(rdateValue)
		from netbluemind.icalendar.api.ICalendarElementRRule import ICalendarElementRRule
		from netbluemind.icalendar.api.ICalendarElementRRule import __ICalendarElementRRuleSerDer__
		rruleValue = value['rrule']
		instance.rrule = __ICalendarElementRRuleSerDer__().parse(rruleValue)
		urlValue = value['url']
		instance.url = serder.STRING.parse(urlValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dtstartValue = value.dtstart
		instance["dtstart"] = __BmDateTimeSerDer__().encode(dtstartValue)
		summaryValue = value.summary
		instance["summary"] = serder.STRING.encode(summaryValue)
		from netbluemind.icalendar.api.ICalendarElementClassification import ICalendarElementClassification
		from netbluemind.icalendar.api.ICalendarElementClassification import __ICalendarElementClassificationSerDer__
		classificationValue = value.classification
		instance["classification"] = __ICalendarElementClassificationSerDer__().encode(classificationValue)
		locationValue = value.location
		instance["location"] = serder.STRING.encode(locationValue)
		descriptionValue = value.description
		instance["description"] = serder.STRING.encode(descriptionValue)
		priorityValue = value.priority
		instance["priority"] = serder.INT.encode(priorityValue)
		from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
		from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
		alarmValue = value.alarm
		instance["alarm"] = serder.ListSerDer(__ICalendarElementVAlarmSerDer__()).encode(alarmValue)
		from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
		from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
		statusValue = value.status
		instance["status"] = __ICalendarElementStatusSerDer__().encode(statusValue)
		from netbluemind.icalendar.api.ICalendarElementAttendee import ICalendarElementAttendee
		from netbluemind.icalendar.api.ICalendarElementAttendee import __ICalendarElementAttendeeSerDer__
		attendeesValue = value.attendees
		instance["attendees"] = serder.ListSerDer(__ICalendarElementAttendeeSerDer__()).encode(attendeesValue)
		from netbluemind.icalendar.api.ICalendarElementOrganizer import ICalendarElementOrganizer
		from netbluemind.icalendar.api.ICalendarElementOrganizer import __ICalendarElementOrganizerSerDer__
		organizerValue = value.organizer
		instance["organizer"] = __ICalendarElementOrganizerSerDer__().encode(organizerValue)
		from netbluemind.tag.api.TagRef import TagRef
		from netbluemind.tag.api.TagRef import __TagRefSerDer__
		categoriesValue = value.categories
		instance["categories"] = serder.ListSerDer(__TagRefSerDer__()).encode(categoriesValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		exdateValue = value.exdate
		instance["exdate"] = serder.SetSerDer(__BmDateTimeSerDer__()).encode(exdateValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		rdateValue = value.rdate
		instance["rdate"] = serder.SetSerDer(__BmDateTimeSerDer__()).encode(rdateValue)
		from netbluemind.icalendar.api.ICalendarElementRRule import ICalendarElementRRule
		from netbluemind.icalendar.api.ICalendarElementRRule import __ICalendarElementRRuleSerDer__
		rruleValue = value.rrule
		instance["rrule"] = __ICalendarElementRRuleSerDer__().encode(rruleValue)
		urlValue = value.url
		instance["url"] = serder.STRING.encode(urlValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum

class ICalendarElementVAlarmAction(Enum):
	Audio = 'Audio';
	Display = 'Display';
	Email = 'Email';

class __ICalendarElementVAlarmActionSerDer__:
	def __init__( self):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementVAlarmAction[value]
		return instance


	def encode(self, value):
		if(value == None):
			return None
		instance = value.value
		return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class IMMessage :
	def __init__( self):
		self.timestamp = None
		self.from_ = None
		self.to = None
		self.body = None
		pass

class __IMMessageSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = IMMessage()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		timestampValue = value['timestamp']
		instance.timestamp = serder.DATE.parse(timestampValue)
		from_Value = value['from']
		instance.from_ = serder.STRING.parse(from_Value)
		toValue = value['to']
		instance.to = serder.STRING.parse(toValue)
		bodyValue = value['body']
		instance.body = serder.STRING.parse(bodyValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		timestampValue = value.timestamp
		instance["timestamp"] = serder.DATE.encode(timestampValue)
		from_Value = value.from_
		instance["from"] = serder.STRING.encode(from_Value)
		toValue = value.to
		instance["to"] = serder.STRING.encode(toValue)
		bodyValue = value.body
		instance["body"] = serder.STRING.encode(bodyValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class SubscriptionInformationsInstallationIndicator :
	def __init__( self):
		self.kind = None
		self.maxValue = None
		self.currentValue = None
		pass

class __SubscriptionInformationsInstallationIndicatorSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = SubscriptionInformationsInstallationIndicator()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import SubscriptionInformationsInstallationIndicatorKind
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import __SubscriptionInformationsInstallationIndicatorKindSerDer__
		kindValue = value['kind']
		instance.kind = __SubscriptionInformationsInstallationIndicatorKindSerDer__().parse(kindValue)
		maxValueValue = value['maxValue']
		instance.maxValue = serder.INT.parse(maxValueValue)
		currentValueValue = value['currentValue']
		instance.currentValue = serder.INT.parse(currentValueValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import SubscriptionInformationsInstallationIndicatorKind
		from netbluemind.system.api.SubscriptionInformationsInstallationIndicatorKind import __SubscriptionInformationsInstallationIndicatorKindSerDer__
		kindValue = value.kind
		instance["kind"] = __SubscriptionInformationsInstallationIndicatorKindSerDer__().encode(kindValue)
		maxValueValue = value.maxValue
		instance["maxValue"] = serder.INT.encode(maxValueValue)
		currentValueValue = value.currentValue
		instance["currentValue"] = serder.INT.encode(currentValueValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class RestoreDefinition :
	def __init__( self):
		self.generation = None
		self.restoreOperationIdenfitier = None
		self.item = None
		pass

class __RestoreDefinitionSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = RestoreDefinition()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		generationValue = value['generation']
		instance.generation = serder.INT.parse(generationValue)
		restoreOperationIdenfitierValue = value['restoreOperationIdenfitier']
		instance.restoreOperationIdenfitier = serder.STRING.parse(restoreOperationIdenfitierValue)
		from netbluemind.dataprotect.api.Restorable import Restorable
		from netbluemind.dataprotect.api.Restorable import __RestorableSerDer__
		itemValue = value['item']
		instance.item = __RestorableSerDer__().parse(itemValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		generationValue = value.generation
		instance["generation"] = serder.INT.encode(generationValue)
		restoreOperationIdenfitierValue = value.restoreOperationIdenfitier
		instance["restoreOperationIdenfitier"] = serder.STRING.encode(restoreOperationIdenfitierValue)
		from netbluemind.dataprotect.api.Restorable import Restorable
		from netbluemind.dataprotect.api.Restorable import __RestorableSerDer__
		itemValue = value.item
		instance["item"] = __RestorableSerDer__().encode(itemValue)
		return instance

